@@ -1057,7 +1057,8 @@
             var domain = this.search_domain(search_string, true);
 
             var context = this.context;
-            if (this.screen_container.but_active.hasClass('active')) {
+            if ((this.screen_container.but_active.css('display') != 'none') &&
+                this.screen_container.but_active.hasClass('active')) {
                 context.active_test = false;
             }
             var search = function() {
@@ -1138,7 +1139,8 @@
             } else {
                 domain = this.domain;
             }
-            if (this.screen_container.but_active.hasClass('active')) {
+            if ((this.screen_container.but_active.css('display') != 'none') &&
+                this.screen_container.but_active.hasClass('active')) {
                 if (!jQuery.isEmptyObject(domain)) {
                     domain = [domain, ['active', '=', false]];
                 } else {
@@ -1325,6 +1327,17 @@
                         deferreds.push(this.views[i].display());
                     }
                 }
+                if (this.current_view.view_type == 'tree') {
+                    var view_tree = this.fields_view_tree[
+                        this.current_view.view_id] || {};
+                    if ('active' in view_tree.fields) {
+                        this.screen_container.but_active.show();
+                    } else {
+                        this.screen_container.but_active.hide();
+                    }
+                } else {
+                    this.screen_container.but_active.hide();
+                }
             }
             return jQuery.when.apply(jQuery, deferreds).then(function() {
                 return this.set_tree_state().then(function() {
@@ -1763,12 +1776,6 @@
                 fields = dom_fields;
             }
 
-            if ('active' in view_tree.fields) {
-                this.screen_container.but_active.show();
-            } else {
-                this.screen_container.but_active.hide();
-            }
-
             // Add common fields
             [
                 ['id', Sao.i18n.gettext('ID'), 'integer'],
