@@ -153,8 +153,7 @@
                 }
             }.bind(this));
 
-            var readonly = (this.screen.attributes.readonly ||
-                    this.screen.group.readonly);
+            var readonly = this.screen.readonly || this.screen.group.readonly;
 
             this._initial_value = null;
             if (view_type == 'form') {
@@ -191,7 +190,7 @@
                 }.bind(this)));
             }
 
-            if (this.save_current) {
+            if (this.save_current && !readonly) {
                 dialog.footer.append(jQuery('<button/>', {
                     'class': 'btn btn-primary',
                     'type': 'submit'
@@ -347,7 +346,7 @@
             var name = '_';
             var access = Sao.common.MODELACCESS.get(this.screen.model_name);
             var deletable = this.screen.deletable;
-            var readonly = this.screen.group.readonly || this.screen.readonly;
+            var readonly = this.screen.readonly || this.screen.group.readonly;
             if (data[0] >= 1) {
                 name = data[0];
                 if (this.domain) {
@@ -424,7 +423,7 @@
         response: function(response_id) {
             var result;
             this.screen.current_view.set_value();
-            var readonly = this.screen.group.readonly;
+            var readonly = this.screen.readonly || this.screen.group.readonly;
             if (~['RESPONSE_OK', 'RESPONSE_ACCEPT'].indexOf(response_id) &&
                     !readonly &&
                     this.screen.current_record) {
@@ -897,7 +896,7 @@
     });
 
     Sao.Window.Revision = Sao.class_(Object, {
-        init: function(revisions, callback) {
+        init: function(revisions, revision, callback) {
             this.callback = callback;
             var dialog = new Sao.Dialog(
                     Sao.i18n.gettext('Revision'), '', 'lg');
@@ -938,13 +937,16 @@
             }));
             revisions.forEach(function(revision) {
                 var name = revision[2];
-                revision = revision[0];
+                rev = revision[0];
                 this.select.append(jQuery('<option/>', {
-                    value: revision.valueOf(),
+                    value: rev.valueOf(),
                     text: Sao.common.format_datetime(
-                        date_format + ' ' + time_format, revision) + ' ' + name,
+                        date_format + ' ' + time_format, rev) + ' ' + name,
                 }));
             }.bind(this));
+            if (revision) {
+                this.select.val(revision.valueOf());
+            }
             this.el.modal('show');
             this.el.on('hidden.bs.modal', function(event) {
                 jQuery(this).remove();
